---
title: <span class="badge builder"></span> CookiePreferences
---
# <span class="badge builder"></span> CookiePreferences

## Constructor

```python
CookiePreferences()
```
## Methods

### <span class="badge object-method"></span> build

Builds the object.

```python
def build() -> preferences.CookiePreferences
```

### <span class="badge object-method"></span> analytics

```python
def analytics(analytics: object) -> typing.Self
```

### <span class="badge object-method"></span> functional

```python
def functional(functional: object) -> typing.Self
```

### <span class="badge object-method"></span> performance

```python
def performance(performance: object) -> typing.Self
```

## See also

 * <span class="badge object-type-class"></span> [CookiePreferences](./object-CookiePreferences.md)
